==> elgg-3.0.5.zip: elgg-3.0.5/mod/groups/languages/fi.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Ryhmät",
	'groups:owned' => "Ryhmät, jotka omistan",
	'groups:owned:user' => 'Käyttäjän %s omistamat ryhmät',
	'groups:yours' => "Omat ryhmäni",
	'groups:user' => "Käyttäjän %s ryhmät",
	'groups:all' => "Kaikki ryhmät",
	'groups:add' => "Luo uusi ryhmä",
	'groups:edit' => "Muokkaa ryhmää",
	'groups:delete' => 'Poista ryhmä',
	'groups:membershiprequests' => 'Hallinnoi liittymispyyntöjä',
	'groups:membershiprequests:pending' => 'Hallinnoi liittymispyyntöjä (%s)',
	'groups:invitations' => 'Ryhmäkutsut',
	'groups:invitations:pending' => 'Ryhmäkutsut (%s)',

	'groups:icon' => 'Ryhmän kuvake (jätä tyhjäksi, jos et halua vaihtaa)',
	'groups:name' => 'Ryhmän nimi',
	'groups:description' => 'Kuvaus',
	'groups:briefdescription' => 'Lyhyt kuvaus',
	'groups:interests' => 'Tagit',
	'groups:website' => 'Nettisivu',
	'groups:members' => 'Ryhmän jäsenet',

	'groups:members_count' => '%s members',

	'groups:members:title' => 'Jäsenet ryhmässä: %s',
	'groups:members:more' => "Näytä kaikki jäsenet",
	'groups:membership' => "Ryhmän jäsenyysasetukset",
	'groups:content_access_mode' => "Pääsy ryhmän sisältöihin",
	'groups:content_access_mode:warning' => "Varoitus: Asetuksen muuttaminen vaikuttaa vain uusiin sisältöihin.",
	'groups:content_access_mode:unrestricted' => "Rajoittamaton - Näkyvyys riippuu kunkin sisällön omasta näkyvyystasosta",
	'groups:content_access_mode:membersonly' => "Vain jäsenet - Ryhmän ulkopuoliset eivät pääse ollenkaan käsiksi sisältöihin",
	'groups:access' => "Pääsyoikeudet",
	'groups:owner' => "Omistaja",
	'groups:owner:warning' => "Varoitus: Jos muutat tätä, luovut ryhmän omistajuudesta.",
	'groups:widget:num_display' => 'Näytettävien ryhmien määrä',
	'widgets:a_users_groups:name' => 'Group membership',
	'widgets:a_users_groups:description' => 'Display the groups you are a member of on your profile',

	'groups:noaccess' => 'Sinulla ei ole oikeuksia tämän ryhmän näkemiseen',
	'groups:cantcreate' => 'Vain sivuston ylläpitäjät voivat luoda uusia ryhmiä.',
	'groups:cantedit' => 'Voit nyt muokata ryhmää',
	'groups:saved' => 'Ryhmä tallennettu',
	'groups:save_error' => 'Ryhmän tallentaminen epäonnistui',
	'groups:featured' => 'Valikoidut ryhmät',
	'groups:makeunfeatured' => 'Poista mainos',
	'groups:makefeatured' => 'Mainosta ryhmää',
	'groups:featuredon' => '%s on nyt mainostettu ryhmä.',
	'groups:unfeatured' => '%s on poistettu mainostettavista ryhmistä.',
	'groups:featured_error' => 'Virheellinen ryhmä.',
	'groups:nofeatured' => 'Ei valikoituja ryhmiä',
	'groups:joinrequest' => 'Ano jäsenyyttä',
	'groups:join' => 'Liity ryhmään',
	'groups:leave' => 'Eroa ryhmästä',
	'groups:invite' => 'Kutsu ystäviä',
	'groups:invite:title' => 'Kutsu ystäviä ryhmään',
	'groups:invite:friends:help' => 'Search for a friend by name or username and select the friend from the list',
	'groups:invite:resend' => 'Resend the invitations to already invited users',

	'groups:nofriendsatall' => 'Sinulla ei vielä ole ystäviä, joita kutsua!',
	'groups:group' => "Ryhmä",
	'groups:search:tags' => "tagi",
	'groups:search:title' => "Ryhmät, joissa tagi '%s'",
	'groups:search:none' => "Ryhmiä ei löytynyt",
	'groups:search_in_group' => "Etsi tästä ryhmästä",
	'groups:acl' => "Ryhmä: %s",
	'groups:acl:in_context' => 'Group members',

	'groups:notfound' => "Ryhmää ei löytynyt",
	
	'groups:requests:none' => 'Ei odottavia jäsenyyspyyntöjä.',

	'groups:invitations:none' => 'Ei odottavia kutsuja.',

	'groups:open' => "avoin ryhmä",
	'groups:closed' => "suljettu ryhmä",
	'groups:member' => "jäsentä",
	'groups:search' => "Search for groups",

	'groups:more' => 'Lisää ryhmiä',
	'groups:none' => 'Ei ryhmiä',

	/**
	 * Access
	 */
	'groups:access:private' => 'Suljettu - Jäsenet pitää kutsua',
	'groups:access:public' => 'Avoin - Kuka tahansa voi liittyä',
	'groups:access:group' => 'Vain ryhmän jäsenet',
	'groups:closedgroup' => "Tällä ryhmällä on suljettu jäsenyys.",
	'groups:closedgroup:request' => 'Klikkaa linkkiä "Ano jäsenyyttä" päästäksesi jäseneksi.',
	'groups:closedgroup:membersonly' => "Tällä ryhmällä on suljettu jäsenyys, ja vain jäsenet pääsevät käsiksi sen sisältöihin.",
	'groups:opengroup:membersonly' => "Vain jäsenillä on pääsy tämän ryhmän sisältöihin.",
	'groups:opengroup:membersonly:join' => 'Klikkaa "Liity ryhmään" päästäksesi ryhmän jäseneksi.',
	'groups:visibility' => 'Kuka voi nähdä tämän ryhmän?',

	/**
	 * Group tools
	 */

	'admin:groups' => 'Ryhmät',

	'groups:notitle' => 'Ryhmällä pitää olla nimi',
	'groups:cantjoin' => 'Ryhmään liittyminen epäonnistui',
	'groups:cantleave' => 'Ryhmästä eroaminen epäonnistui',
	'groups:removeuser' => 'Poista ryhmästä',
	'groups:cantremove' => 'Käyttäjää ei voida poistaa ryhmästä',
	'groups:removed' => 'Käyttäjä %s poistettiin ryhmästä',
	'groups:addedtogroup' => 'Käyttäjä lisättiin ryhmään',
	'groups:joinrequestnotmade' => 'Ryhmän jäsenyyden anominen epäonnistui',
	'groups:joinrequestmade' => 'Lähetettiin pyyntö päästä ryhmän jäseneksi',
	'groups:joinrequest:exists' => 'Olet jo anonut jäsenyyttä tähän ryhmään',
	'groups:button:joined' => 'Joined',
	'groups:button:owned' => 'Owned',
	'groups:joined' => 'Olet nyt ryhmän jäsen!',
	'groups:left' => 'Olet nyt eronnut ryhmästä',
	'groups:userinvited' => 'Käyttäjä kutsuttu.',
	'groups:usernotinvited' => 'Käyttäjän kutsuminen epäonnistui.',
	'groups:useralreadyinvited' => 'Käyttäjä on jo kutsuttu',
	'groups:invite:subject' => "%s sinut on kutsuttu ryhmän %s jäseneksi!",
	'groups:joinrequest:remove:check' => 'Haluatko varmasti poistaa tämän liittymispyynnön?',
	'groups:invite:remove:check' => 'Haluatko varmasti poistaa tämän kutsun?',
	'groups:invite:body' => "Hi %s,

%s invited you to join the '%s' group.

Click below to view your invitations:
%s",

	'groups:welcome:subject' => "Tervetuloa ryhmään %s!",
	'groups:welcome:body' => "Hi %s!

You are now a member of the '%s' group.

Click below to begin posting!
%s",

	'groups:request:subject' => "%s on anonut jäsenyyttä ryhmään %s",
	'groups:request:body' => "Hi %s,

%s has requested to join the '%s' group.

Click below to view their profile:
%s

or click below to view the group's join requests:
%s",

	'river:group:create' => '%s created the group %s',
	'river:group:join' => '%s joined the group %s',

	'groups:allowhiddengroups' => 'Sallitaanko suljettujen (piilotettujen) ryhmien luominen?',
	'groups:whocancreate' => 'Kuka voi luoda uusia ryhmiä?',

	/**
	 * Action messages
	 */
	'groups:deleted' => 'Group and group contents deleted',
	'groups:notdeleted' => 'Group could not be deleted',
	'groups:deletewarning' => "Haluatko varmasti poistaa tämän ryhmän? Tätä toimintoa ei voi perua!",

	'groups:invitekilled' => 'Kutsu poistettu.',
	'groups:joinrequestkilled' => 'Pyyntö poistettu.',
	'groups:error:addedtogroup' => "Käyttäjän %s lisääminen epäonnistui",
	'groups:add:alreadymember' => "%s on jo tämän ryhmän jäsen",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Ryhmät',

	/**
	 * Upgrades
	 */
	'groups:upgrade:2016101900:title' => 'Transfer group icons to new location',
	'groups:upgrade:2016101900:description' => 'New entity icon API stores icons in a predictable location on the filestore
relative to the entity\'s filestore directory. This upgrade aligns will align group plugin with the requirements of the new API.',
);

==> elgg-3.3.20.zip: elgg-3.3.20/mod/groups/languages/fi.php <==
<?php
/**
 * Translation file
 *
 * Note: don't change the return array to short notation because Transifex can't handle those during `tx push -s`
 */

return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Ryhmät",
	'groups:owned' => "Ryhmät, jotka omistan",
	'groups:owned:user' => 'Käyttäjän %s omistamat ryhmät',
	'groups:yours' => "Omat ryhmäni",
	'groups:user' => "Käyttäjän %s ryhmät",
	'groups:all' => "Kaikki ryhmät",
	'groups:add' => "Luo uusi ryhmä",
	'groups:edit' => "Muokkaa ryhmää",
	'groups:delete' => 'Poista ryhmä',
	'groups:membershiprequests' => 'Hallinnoi liittymispyyntöjä',
	'groups:membershiprequests:pending' => 'Hallinnoi liittymispyyntöjä (%s)',
	'groups:invitedmembers' => "Manage invitations",
	'groups:invitations' => 'Ryhmäkutsut',
	'groups:invitations:pending' => 'Ryhmäkutsut (%s)',
	
	'relationship:invited' => '%2$s was invited to join %1$s',
	'relationship:membership_request' => '%s requested to join %s',

	'groups:icon' => 'Ryhmän kuvake (jätä tyhjäksi, jos et halua vaihtaa)',
	'groups:name' => 'Ryhmän nimi',
	'groups:description' => 'Kuvaus',
	'groups:briefdescription' => 'Lyhyt kuvaus',
	'groups:interests' => 'Tagit',
	'groups:website' => 'Nettisivu',
	'groups:members' => 'Ryhmän jäsenet',

	'groups:members_count' => '%s members',

	'groups:members:title' => 'Jäsenet ryhmässä: %s',
	'groups:members:more' => "Näytä kaikki jäsenet",
	'groups:membership' => "Ryhmän jäsenyysasetukset",
	'groups:content_access_mode' => "Pääsy ryhmän sisältöihin",
	'groups:content_access_mode:warning' => "Varoitus: Asetuksen muuttaminen vaikuttaa vain uusiin sisältöihin.",
	'groups:content_access_mode:unrestricted' => "Rajoittamaton - Näkyvyys riippuu kunkin sisällön omasta näkyvyystasosta",
	'groups:content_access_mode:membersonly' => "Vain jäsenet - Ryhmän ulkopuoliset eivät pääse ollenkaan käsiksi sisältöihin",
	'groups:access' => "Pääsyoikeudet",
	'groups:owner' => "Omistaja",
	'groups:owner:warning' => "Varoitus: Jos muutat tätä, luovut ryhmän omistajuudesta.",
	'groups:widget:num_display' => 'Näytettävien ryhmien määrä',
	'widgets:a_users_groups:name' => 'Ryhmien jäsenyys',
	'widgets:a_users_groups:description' => 'Näytä profiilissasi ryhmät, joiden jäsenenä olet',

	'groups:noaccess' => 'Sinulla ei ole oikeuksia tämän ryhmän näkemiseen',
	'groups:cantcreate' => 'Vain sivuston ylläpitäjät voivat luoda uusia ryhmiä.',
	'groups:cantedit' => 'Voit nyt muokata ryhmää',
	'groups:saved' => 'Ryhmä tallennettu',
	'groups:save_error' => 'Ryhmän tallentaminen epäonnistui',
	'groups:featured' => 'Valikoidut ryhmät',
	'groups:makeunfeatured' => 'Poista mainos',
	'groups:makefeatured' => 'Mainosta ryhmää',
	'groups:featuredon' => '%s on nyt mainostettu ryhmä.',
	'groups:unfeatured' => '%s on poistettu mainostettavista ryhmistä.',
	'groups:featured_error' => 'Virheellinen ryhmä.',
	'groups:nofeatured' => 'Ei valikoituja ryhmiä',
	'groups:joinrequest' => 'Ano jäsenyyttä',
	'groups:join' => 'Liity ryhmään',
	'groups:leave' => 'Eroa ryhmästä',
	'groups:invite' => 'Kutsu ystäviä',
	'groups:invite:title' => 'Kutsu ystäviä ryhmään',
	'groups:invite:friends:help' => 'Search for a friend by name or username and select the friend from the list',
	'groups:invite:resend' => 'Resend the invitations to already invited users',
	'groups:invite:member' => 'Already a member of this group',
	'groups:invite:invited' => 'Already invited to this group',

	'groups:nofriendsatall' => 'Sinulla ei vielä ole ystäviä, joita kutsua!',
	'groups:group' => "Ryhmä",
	'groups:search:tags' => "tagi",
	'groups:search:title' => "Ryhmät, joissa tagi '%s'",
	'groups:search:none' => "Ryhmiä ei löytynyt",
	'groups:search_in_group' => "Etsi tästä ryhmästä",
	'groups:acl' => "Ryhmä: %s",
	'groups:acl:in_context' => 'Ryhmän jäsenet',

	'groups:notfound' => "Ryhmää ei löytynyt",
	
	'groups:requests:none' => 'Ei odottavia jäsenyyspyyntöjä.',

	'groups:invitations:none' => 'Ei odottavia kutsuja.',

	'groups:open' => "avoin ryhmä",
	'groups:closed' => "suljettu ryhmä",
	'groups:member' => "jäsentä",
	'groups:search' => "Search for groups",

	'groups:more' => 'Lisää ryhmiä',
	'groups:none' => 'Ei ryhmiä',

	/**
	 * Access
	 */
	'groups:access:private' => 'Suljettu - Jäsenet pitää kutsua',
	'groups:access:public' => 'Avoin - Kuka tahansa voi liittyä',
	'groups:access:group' => 'Vain ryhmän jäsenet',
	'groups:closedgroup' => "Tällä ryhmällä on suljettu jäsenyys.",
	'groups:closedgroup:request' => 'Klikkaa linkkiä "Ano jäsenyyttä" päästäksesi jäseneksi.',
	'groups:closedgroup:membersonly' => "Tällä ryhmällä on suljettu jäsenyys, ja vain jäsenet pääsevät käsiksi sen sisältöihin.",
	'groups:opengroup:membersonly' => "Vain jäsenillä on pääsy tämän ryhmän sisältöihin.",
	'groups:opengroup:membersonly:join' => 'Klikkaa "Liity ryhmään" päästäksesi ryhmän jäseneksi.',
	'groups:visibility' => 'Kuka voi nähdä tämän ryhmän?',
	'groups:content_default_access' => 'Default group content access',
	'groups:content_default_access:help' => 'Here you can configure the default access for new content in this group. The group content mode can prevent the selected option from being in effect.',
	'groups:content_default_access:not_configured' => 'No default access configured, leave to the user',

	/**
	 * Group tools
	 */

	'admin:groups' => 'Ryhmät',

	'groups:notitle' => 'Ryhmällä pitää olla nimi',
	'groups:cantjoin' => 'Ryhmään liittyminen epäonnistui',
	'groups:cantleave' => 'Ryhmästä eroaminen epäonnistui',
	'groups:removeuser' => 'Poista ryhmästä',
	'groups:cantremove' => 'Käyttäjää ei voida poistaa ryhmästä',
	'groups:removed' => 'Käyttäjä %s poistettiin ryhmästä',
	'groups:addedtogroup' => 'Käyttäjä lisättiin ryhmään',
	'groups:joinrequestnotmade' => 'Ryhmän jäsenyyden anominen epäonnistui',
	'groups:joinrequestmade' => 'Lähetettiin pyyntö päästä ryhmän jäseneksi',
	'groups:joinrequest:exists' => 'Olet jo anonut jäsenyyttä tähän ryhmään',
	'groups:button:joined' => 'Joined',
	'groups:button:owned' => 'Owned',
	'groups:joined' => 'Olet nyt ryhmän jäsen!',
	'groups:left' => 'Olet nyt eronnut ryhmästä',
	'groups:userinvited' => 'Käyttäjä kutsuttu.',
	'groups:usernotinvited' => 'Käyttäjän kutsuminen epäonnistui.',
	'groups:useralreadyinvited' => 'Käyttäjä on jo kutsuttu',
	'groups:invite:subject' => "%s sinut on kutsuttu ryhmän %s jäseneksi!",
	'groups:joinrequest:remove:check' => 'Haluatko varmasti poistaa tämän liittymispyynnön?',
	'groups:invite:remove:check' => 'Haluatko varmasti poistaa tämän kutsun?',
	'groups:invite:body' => "Hi %s,

%s invited you to join the '%s' group.

Click below to view your invitations:
%s",

	'groups:welcome:subject' => "Tervetuloa ryhmään %s!",
	'groups:welcome:body' => "Hi %s!

You are now a member of the '%s' group.

Click below to begin posting!
%s",

	'groups:request:subject' => "%s on anonut jäsenyyttä ryhmään %s",
	'groups:request:body' => "Hi %s,

%s has requested to join the '%s' group.

Click below to view their profile:
%s

or click below to view the group's join requests:
%s",

	'river:group:create' => '%s created the group %s',
	'river:group:join' => '%s joined the group %s',

	'groups:allowhiddengroups' => 'Sallitaanko suljettujen (piilotettujen) ryhmien luominen?',
	'groups:whocancreate' => 'Kuka voi luoda uusia ryhmiä?',

	/**
	 * Action messages
	 */
	'groups:deleted' => 'Group and group contents deleted',
	'groups:notdeleted' => 'Group could not be deleted',
	'groups:deletewarning' => "Haluatko varmasti poistaa tämän ryhmän? Tätä toimintoa ei voi perua!",

	'groups:invitekilled' => 'Kutsu poistettu.',
	'groups:joinrequestkilled' => 'Pyyntö poistettu.',
	'groups:error:addedtogroup' => "Käyttäjän %s lisääminen epäonnistui",
	'groups:add:alreadymember' => "%s on jo tämän ryhmän jäsen",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Ryhmät',

	/**
	 * Upgrades
	 */
	'groups:upgrade:2016101900:title' => 'Transfer group icons to a new location',
	'groups:upgrade:2016101900:description' => 'New entity icon API stores icons in a predictable location on the filestore
relative to the entity\'s filestore directory. This upgrade will align the group plugin with the requirements of the new API.',
);
